#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from Point2D import Point2D

class Path():
    """
    Basic class for representing robot path in free space 
    Data entries:
    Point2D[] coords
    """
    __attributes__ = ['coords']
    __attribute_types = ['Point2D[]']
    
    def __init__(self):
        self.coords = []

    def plot(self, ax, skipstep=1, style='frame', clr=[1,0,0]):
        """ 2D plot of the path 
        Args:
            ax: plt figure axes
            skipstep: show only each n-th coords
        """
        if style=='frame': 
            for idx, coords in enumerate(self.coords):
                if idx % skipstep == 0:
                    coords.plot(ax, style=style, clr=clr)
        elif style == 'point':
            coords = np.asarray([(coords.x, coords.y) for coords in self.coords])
            if ax.name == '3d':
                ax.plot(coords[::skipstep,0], coords[::skipstep,1], coords[::skipstep, 2],  '.', color=clr)
                ax.plot(coords[::skipstep,0], coords[::skipstep,1], coords[::skipstep, 2],  '-', color=clr)
            else:
                ax.plot(coords[::skipstep,0], coords[::skipstep,1], '.', color=clr)
                ax.plot(coords[::skipstep,0], coords[::skipstep,1], '-', color=clr)


#Examples of usage
if __name__=="__main__":
    path = Path()
    path.coords.append(Point2D(1, 2))
    path.coords.append(Point2D(2, 3))
    path.coords.append(Point2D(3, 4))

    for coords in path.coords:
        print(coords.x, 
              coords.y)


